==> vice_1.16.orig.tar.gz: vice-1.16/src/gfxoutputdrv/ffmpegdrv.h <==
/*
 * ffmpegdrv.h - Movie driver using FFMPEG library and screenshot API.
 *
 * Written by
 *  Andreas Matthies <andreas.matthies@gmx.net>
 *
 * This file is part of VICE, the Versatile Commodore Emulator.
 * See README for copyright notice.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 *  02111-1307  USA.
 *
 */

#ifndef _FFMPEGDRV_H
#define _FFMPEGDRV_H

#include "screenshot.h"

typedef struct ffmpegdrv_audio_in_s {
    SWORD *buffer;
    int buffersamples;
    int used;
} ffmpegdrv_audio_in_t;

extern void gfxoutput_init_ffmpeg(void);
extern void ffmpegdrv_init_audio(int speed, int channels, 
                               ffmpegdrv_audio_in_t** audio_in);
extern void ffmpegdrv_encode_audio(ffmpegdrv_audio_in_t *audio_in);
extern int  ffmpegdrv_resources_init(void);
extern int ffmpegdrv_cmdline_options_init(void);
extern void ffmpegdrv_shutdown(void);

#endif

==> vice_1.20.orig.tar.gz: vice-1.20/src/gfxoutputdrv/ffmpegdrv.h <==
/*
 * ffmpegdrv.h - Movie driver using FFMPEG library and screenshot API.
 *
 * Written by
 *  Andreas Matthies <andreas.matthies@gmx.net>
 *
 * This file is part of VICE, the Versatile Commodore Emulator.
 * See README for copyright notice.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 *  02111-1307  USA.
 *
 */

#ifndef _FFMPEGDRV_H
#define _FFMPEGDRV_H

#include "screenshot.h"

typedef struct ffmpegdrv_audio_in_s {
    SWORD *buffer;
    int buffersamples;
    int used;
} ffmpegdrv_audio_in_t;

typedef struct ffmpegdrv_codec_s {
    int id;
    const char *name;
} ffmpegdrv_codec_t;

typedef struct ffmpegdrv_format_s {
    char *name;
    ffmpegdrv_codec_t *audio_codecs;
    ffmpegdrv_codec_t *video_codecs;
} ffmpegdrv_format_t;

extern ffmpegdrv_format_t ffmpegdrv_formatlist[];

extern void gfxoutput_init_ffmpeg(void);
extern void ffmpegdrv_init_audio(int speed, int channels, 
                               ffmpegdrv_audio_in_t** audio_in);
extern void ffmpegdrv_encode_audio(ffmpegdrv_audio_in_t *audio_in);
extern int  ffmpegdrv_resources_init(void);
extern int ffmpegdrv_cmdline_options_init(void);
extern void ffmpegdrv_shutdown(void);

#endif
